using System;
using System.IO;
using System.Windows.Documents;
using System.Windows.Xps.Packaging;
using System.Windows.Media.Imaging;


namespace xpstojpeg
{
    static public class XpsJpegHelper
    {
        private class ShowHelpException : Exception {}

        static public void SaveXpsPageToJpeg(string xpsFileName, int[] pages)
        {
            XpsDocument xpsDoc = new XpsDocument(xpsFileName, System.IO.FileAccess.Read);
            FixedDocumentSequence docSeq = xpsDoc.GetFixedDocumentSequence();

            // You can get the total page count from docSeq.PageCount

            foreach (int pageNum in pages)
            {
                DocumentPaginator paginator = docSeq.DocumentPaginator;
                DocumentPage docPage = paginator.GetPage(pageNum);
                BitmapImage bitmap = new BitmapImage();
                RenderTargetBitmap renderTarget =
                    new RenderTargetBitmap( (int) docPage.Size.Width,
                                            (int) docPage.Size.Height,
                                            96, // WPF (Avalon) units are 96dpi based
                                            96,
                                            System.Windows.Media.PixelFormats.Default);

                renderTarget.Render(docPage.Visual);

                JpegBitmapEncoder encoder = new JpegBitmapEncoder();  // Choose type here ie: JpegBitmapEncoder, etc
                encoder.Frames.Add(BitmapFrame.Create(renderTarget));

                FileStream pageOutStream = new FileStream(xpsDoc + ".Page" + pageNum + ".jpg", FileMode.Create, FileAccess.Write);
                encoder.Save(pageOutStream);
                pageOutStream.Close();
            }
        }

        [STAThread()]
        public static void Main(string[] args)
        {
             try
             {
                 if (0 == args.Length)
                     throw new ShowHelpException();

                 foreach(string argument in args)
                 {
                     if ("-?" == argument)
                         throw new ShowHelpException();
                     if ("/?" == argument)
                         throw new ShowHelpException();
                     if ("-help" == argument)
                         throw new ShowHelpException();
                     if ("--help" == argument)
                         throw new ShowHelpException();
                 }

                 int[] pages = new int[] { 0 };

                 foreach(string argument in args)
                 {
                     XpsJpegHelper.SaveXpsPageToJpeg(argument, pages);
                 }

             }
             catch (ShowHelpException)
             {
                 Console.WriteLine("input like \"myfile\" ... that's all folks!");
             }
             catch(Exception ex)
             {
                 Console.WriteLine(string.Format("Error: {0}", ex.Message));
             }
        }
    }
}